==> TopdataTopFeedSW6-v7.0.11.zip: TopdataTopFeedSW6/manual/topfeed-configuration.de.md <==
# TopFEED Konfigurationsleitfaden

## Übersicht
TopFEED ist ein Shopware-Plugin zur Verwaltung und Anzeige von Produktdaten. Diese Dokumentation beschreibt die verfügbaren Konfigurationsoptionen.

## Plugin-Information
- **Version**: 1.0.1
- **Kompatibilität**: Shopware 6.3.0.0 - 6.5.5.2
- **Support**: shopware@topdata.de

## Features
* Hochwertige Produktdaten aus eigener Pflege
* Cross & Upselling
* Artikeleigenschaften & Spezifikationen

## Konfigurationsoptionen

### Grundeinstellungen
1. **Verkaufskanal**
   - Wählen Sie den Verkaufskanal, für den die Einstellungen gelten sollen

### Produktdaten-Import
2. **Produktname importieren**
   - Legen Sie fest, ob der von uns definierte Produktname oder Ihr eigener verwendet werden soll

3. **Produktbeschreibung importieren**
   - Legen Sie fest, ob die von uns definierte Produktbeschreibung oder Ihre eigene verwendet werden soll

4. **Produkthersteller**
   - Legen Sie fest, ob der von uns definierte Produkthersteller oder Ihr eigener verwendet werden soll

5. **EANs importieren**
   - Legen Sie fest, ob die EAN-Nummer des Artikels importiert werden soll

6. **OEMs importieren**
   - Legen Sie fest, ob die OEM-Nummer des Artikels importiert werden soll

### Produktbilder
7. **Produktbilder**
   - Legen Sie fest, ob unsere Produktbilder oder Ihre eigenen verwendet werden sollen

8. **Alte Bilder löschen**
   - Legen Sie fest, ob nicht mehr aktuelle Produktbilder gelöscht werden sollen

### Produkteigenschaften
9. **Produkteigenschaften**
   - Legen Sie fest, ob von uns definierte Spezifikationen importiert werden sollen
   - Beispiele: Kapazität, Farbe, Produktart, etc.

10. **Referenz-PCDs als Merkmale**
    - Legen Sie fest, ob Referenz-PCDs als Eigenschaften gespeichert werden sollen

11. **Referenz-OEMs als Merkmale**
    - Legen Sie fest, ob Referenz-OEMs als Eigenschaften gespeichert werden sollen

### Kategorien
12. **Produktkategorien**
    - Legen Sie fest, ob Sie von uns angelegte Warengruppen oder Ihre eigenen verwenden möchten

13. **Hauptkategorie**
    - Legen Sie die Hauptwarengruppe für die Produktwarengruppen fest

### Cross-Selling Optionen
14. **Ähnliche Produkte**
    - Import ähnlicher Produkte aktivieren/deaktivieren

15. **Alternative Produkte**
    - Import alternativer Produkte aktivieren/deaktivieren

16. **Verwandte Produkte**
    - Import von Zubehör aktivieren/deaktivieren

17. **Gebündelte Produkte**
    - Import von Produktbundles aktivieren/deaktivieren

18. **Varianten**
    - Import von Produktvarianten aktivieren/deaktivieren

19. **Farbvarianten**
    - Import von Farbvarianten aktivieren/deaktivieren

20. **Kapazitätsvarianten**
    - Import von Kapazitätsvarianten aktivieren/deaktivieren

### Anzeigeeinstellungen

#### Produktdetailseite
21. **Andere Farben - Anzeige**
    - Konfiguration der Anzeige von Farbvarianten

22. **Andere Kapazitäten - Anzeige**
    - Konfiguration der Anzeige von Kapazitätsvarianten

23. **Produktvarianten**
    - Anzeige von Produktvarianten aktivieren/deaktivieren

24. **Andere Farben**
    - Anzeige von Farbvarianten aktivieren/deaktivieren

25. **Andere Kapazitäten**
    - Anzeige von Kapazitätsvarianten aktivieren/deaktivieren

26. **Alternative Produkte**
    - Anzeige alternativer Produkte aktivieren/deaktivieren

27. **Produkte im Bundle**
    - Anzeige von Bundleprodukten aktivieren/deaktivieren

28. **Bündel mit Produkt**
    - Anzeige von Bundles, die das Produkt enthalten, aktivieren/deaktivieren

29. **Zubehör**
    - Anzeige von Zubehör aktivieren/deaktivieren

30. **Ähnliche Produkte**
    - Anzeige ähnlicher Produkte aktivieren/deaktivieren

#### Produkt-Menü
31. **Produktvarianten**
    - Anzeige von Varianten im Menü aktivieren/deaktivieren

32. **Andere Farben**
    - Anzeige von Farbvarianten im Menü aktivieren/deaktivieren

33. **Andere Kapazitäten**
    - Anzeige von Kapazitätsvarianten im Menü aktivieren/deaktivieren

34. **Alternative Produkte**
    - Anzeige alternativer Produkte im Menü aktivieren/deaktivieren

35. **Produkte im Bundle**
    - Anzeige von Bundleprodukten im Menü aktivieren/deaktivieren

36. **Bündel mit Produkt**
    - Anzeige von Bundles im Menü aktivieren/deaktivieren

37. **Zubehör**
    - Anzeige von Zubehör im Menü aktivieren/deaktivieren

38. **Ähnliche Produkte**
    - Anzeige ähnlicher Produkte im Menü aktivieren/deaktivieren

#### Produktliste
39. **Produktvarianten**
    - Anzeige von Varianten in der Liste aktivieren/deaktivieren

40. **Andere Farben**
    - Anzeige von Farbvarianten in der Liste aktivieren/deaktivieren

41. **Andere Kapazitäten**
    - Anzeige von Kapazitätsvarianten in der Liste aktivieren/deaktivieren

42. **Alternative Produkte**
    - Anzeige alternativer Produkte in der Liste aktivieren/deaktivieren

43. **Produkte im Bundle**
    - Anzeige von Bundleprodukten in der Liste aktivieren/deaktivieren

44. **Bündel mit Produkt**
    - Anzeige von Bundles in der Liste aktivieren/deaktivieren

45. **Zubehör**
    - Anzeige von Zubehör in der Liste aktivieren/deaktivieren

46. **Ähnliche Produkte**
    - Anzeige ähnlicher Produkte in der Liste aktivieren/deaktivieren

==> TopdataTopFeedSW6-v7.2.1.zip: TopdataTopFeedSW6/manual/topfeed-configuration.de.md <==
# TopFEED Konfigurationsleitfaden

## Übersicht
TopFEED ist ein Shopware-Plugin zur Verwaltung und Anzeige von Produktdaten. Diese Dokumentation beschreibt die verfügbaren Konfigurationsoptionen.

## Plugin-Information
- **Support**: shopware@topdata.de

## Features
* Hochwertige Produktdaten aus eigener Pflege
* Cross & Upselling
* Artikeleigenschaften & Spezifikationen

## Konfigurationsoptionen

### Grundeinstellungen
1. **Verkaufskanal**
   - Wählen Sie den Verkaufskanal, für den die Einstellungen gelten sollen

### Produktdaten-Import
2. **Produktname importieren**
   - Legen Sie fest, ob der von uns definierte Produktname oder Ihr eigener verwendet werden soll

3. **Produktbeschreibung importieren**
   - Legen Sie fest, ob die von uns definierte Produktbeschreibung oder Ihre eigene verwendet werden soll

4. **Produkthersteller**
   - Legen Sie fest, ob der von uns definierte Produkthersteller oder Ihr eigener verwendet werden soll

5. **EANs importieren**
   - Legen Sie fest, ob die EAN-Nummer des Artikels importiert werden soll

6. **OEMs importieren**
   - Legen Sie fest, ob die OEM-Nummer des Artikels importiert werden soll

### Produktbilder
7. **Produktbilder**
   - Legen Sie fest, ob unsere Produktbilder oder Ihre eigenen verwendet werden sollen

8. **Alte Bilder löschen**
   - Legen Sie fest, ob nicht mehr aktuelle Produktbilder gelöscht werden sollen

### Produkteigenschaften
9. **Produkteigenschaften**
   - Legen Sie fest, ob von uns definierte Spezifikationen importiert werden sollen
   - Beispiele: Kapazität, Farbe, Produktart, etc.

10. **Referenz-PCDs als Merkmale**
    - Legen Sie fest, ob Referenz-PCDs als Eigenschaften gespeichert werden sollen

11. **Referenz-OEMs als Merkmale**
    - Legen Sie fest, ob Referenz-OEMs als Eigenschaften gespeichert werden sollen

### Kategorien
12. **Produktkategorien**
    - Legen Sie fest, ob Sie von uns angelegte Warengruppen oder Ihre eigenen verwenden möchten

13. **Hauptkategorie**
    - Legen Sie die Hauptwarengruppe für die Produktwarengruppen fest

### Cross-Selling Optionen
14. **Ähnliche Produkte**
    - Import ähnlicher Produkte aktivieren/deaktivieren

15. **Alternative Produkte**
    - Import alternativer Produkte aktivieren/deaktivieren

16. **Verwandte Produkte**
    - Import von Zubehör aktivieren/deaktivieren

17. **Gebündelte Produkte**
    - Import von Produktbundles aktivieren/deaktivieren

18. **Varianten**
    - Import von Produktvarianten aktivieren/deaktivieren

19. **Farbvarianten**
    - Import von Farbvarianten aktivieren/deaktivieren

20. **Kapazitätsvarianten**
    - Import von Kapazitätsvarianten aktivieren/deaktivieren

### Anzeigeeinstellungen

#### Produktdetailseite
21. **Andere Farben - Anzeige**
    - Konfiguration der Anzeige von Farbvarianten

22. **Andere Kapazitäten - Anzeige**
    - Konfiguration der Anzeige von Kapazitätsvarianten

23. **Produktvarianten**
    - Anzeige von Produktvarianten aktivieren/deaktivieren

24. **Andere Farben**
    - Anzeige von Farbvarianten aktivieren/deaktivieren

25. **Andere Kapazitäten**
    - Anzeige von Kapazitätsvarianten aktivieren/deaktivieren

26. **Alternative Produkte**
    - Anzeige alternativer Produkte aktivieren/deaktivieren

27. **Produkte im Bundle**
    - Anzeige von Bundleprodukten aktivieren/deaktivieren

28. **Bündel mit Produkt**
    - Anzeige von Bundles, die das Produkt enthalten, aktivieren/deaktivieren

29. **Zubehör**
    - Anzeige von Zubehör aktivieren/deaktivieren

30. **Ähnliche Produkte**
    - Anzeige ähnlicher Produkte aktivieren/deaktivieren

31. **Sortierung der Cross-Selling-Tabs**
    - Wählt die Standardsortierung für Produkte, die in den Cross-Selling-Tabs (z.B. 'Zubehör', 'Ähnliche Artikel') angezeigt werden. Diese Einstellung verwendet die in Shopware unter `Kataloge > Produkte > Sortierung` definierten Sortieroptionen. Wenn keine Sortierung ausgewählt ist, wird standardmäßig nach Produktname (A-Z) sortiert.

#### Produkt-Menü
32. **Produktvarianten**
    - Anzeige von Varianten im Menü aktivieren/deaktivieren

32. **Andere Farben**
    - Anzeige von Farbvarianten im Menü aktivieren/deaktivieren

33. **Andere Kapazitäten**
    - Anzeige von Kapazitätsvarianten im Menü aktivieren/deaktivieren

34. **Alternative Produkte**
    - Anzeige alternativer Produkte im Menü aktivieren/deaktivieren

35. **Produkte im Bundle**
    - Anzeige von Bundleprodukten im Menü aktivieren/deaktivieren

36. **Bündel mit Produkt**
    - Anzeige von Bundles im Menü aktivieren/deaktivieren

37. **Zubehör**
    - Anzeige von Zubehör im Menü aktivieren/deaktivieren

38. **Ähnliche Produkte**
    - Anzeige ähnlicher Produkte im Menü aktivieren/deaktivieren

#### Produktliste
40. **Produktvarianten**
    - Anzeige von Varianten in der Liste aktivieren/deaktivieren

41. **Andere Farben**
    - Anzeige von Farbvarianten in der Liste aktivieren/deaktivieren

42. **Andere Kapazitäten**
    - Anzeige von Kapazitätsvarianten in der Liste aktivieren/deaktivieren

43. **Alternative Produkte**
    - Anzeige alternativer Produkte in der Liste aktivieren/deaktivieren

44. **Produkte im Bundle**
    - Anzeige von Bundleprodukten in der Liste aktivieren/deaktivieren

45. **Bündel mit Produkt**
    - Anzeige von Bundles in der Liste aktivieren/deaktivieren

46. **Zubehör**
    - Anzeige von Zubehör in der Liste aktivieren/deaktivieren

47. **Ähnliche Produkte**
    - Anzeige ähnlicher Produkte in der Liste aktivieren/deaktivieren
